==> haskell-pcre-heavy-1.0.0.2-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-heavy
version: 1.0.0.2
id: pcre-heavy-1.0.0.2-41QU5UsWJsMGC7unxbRGk5
key: pcre-heavy-1.0.0.2-41QU5UsWJsMGC7unxbRGk5
license: LicenseRef-PublicDomain
copyright: 2015 Greg V <greg@unrelenting.technology>
maintainer: greg@unrelenting.technology
author: Greg V
homepage: https://github.com/myfreeweb/pcre-heavy
synopsis: A regexp library on top of pcre-light you can actually use.
description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!
category: Web
abi: 3a617e9d574eb1143dff10137ec1300b
exposed: True
exposed-modules:
    Text.Regex.PCRE.Heavy
import-dirs: /usr/lib/ghc-8.4.3/site-local/pcre-heavy-1.0.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/pcre-heavy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/pcre-heavy-1.0.0.2
hs-libraries: HSpcre-heavy-1.0.0.2-41QU5UsWJsMGC7unxbRGk5
depends:
    base-4.11.1.0 base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6
    pcre-light-0.4.0.4-uOVONiujCrFtQK1BvbOV0 bytestring-0.10.8.2
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.1-LjQCAvvrOQx72iD1hHVjc6=1d75d8a5e04e09d5efbd2d425663f665
             pcre-light-0.4.0.4-uOVONiujCrFtQK1BvbOV0=ade7de6fe1a628e428d66b0f3b406659
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=2754b46212c00717aaae8361f03806b5
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
haddock-interfaces: /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html: /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pcre-heavy-1.0.0.2-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pcre-heavy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pcre-heavy
version: 1.0.0.2
id: pcre-heavy-1.0.0.2-nrMb8X5XE9EINNrJaDCWC
key: pcre-heavy-1.0.0.2-nrMb8X5XE9EINNrJaDCWC
license: LicenseRef-PublicDomain
copyright: 2015 Greg V <greg@unrelenting.technology>
maintainer: greg@unrelenting.technology
author: Greg V
homepage: https://github.com/myfreeweb/pcre-heavy
synopsis: A regexp library on top of pcre-light you can actually use.
description:
    A regular expressions library that does not suck.
    Based on <https://hackage.haskell.org/package/pcre-light pcre-light>.
    Takes and returns <https://hackage.haskell.org/package/stringable Stringables> everywhere.
    Includes a QuasiQuoter for regexps that does compile time checking.
    SEARCHES FOR MULTIPLE MATCHES! DOES REPLACEMENT!
category: Web
abi: 182d5d0ac90a16d038849c2ab9fcd3cd
exposed: True
exposed-modules:
    Text.Regex.PCRE.Heavy
import-dirs: /usr/lib/ghc-8.4.3/site-local/pcre-heavy-1.0.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/pcre-heavy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/pcre-heavy-1.0.0.2
hs-libraries: HSpcre-heavy-1.0.0.2-nrMb8X5XE9EINNrJaDCWC
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    pcre-light-0.4.0.4-uOVONiujCrFtQK1BvbOV0 bytestring-0.10.8.2
    string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT
    template-haskell-2.13.0.0
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=fc280138c1e1b70cf939493d29d4c902
             pcre-light-0.4.0.4-uOVONiujCrFtQK1BvbOV0=ade7de6fe1a628e428d66b0f3b406659
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             string-conversions-0.4.0.1-2odRrDeA1b0G507cZcdaLT=2754b46212c00717aaae8361f03806b5
             template-haskell-2.13.0.0=1ce4a454c5861830bbdedc46baa462f3
haddock-interfaces: /usr/share/doc/haskell-pcre-heavy/html/pcre-heavy.haddock
haddock-html: /usr/share/doc/haskell-pcre-heavy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
